@@ -6,7 +6,7 @@ from dotenv import load_dotenv
 if not load_dotenv(override=False):
     print('Could not find any .env file. The module will depend on system env only')
 
-from config import Config
+from zdynamodb.config import Config
 
 logger = logging.getLogger(os.getenv('APP_NAME', __name__))
 
@@ -19,5 +19,3 @@ if not logger.hasHandlers():
     ch.setFormatter(formatter)
     logger.addHandler(ch)
 
-import dynamo
-import queries
